@@ -8,8 +8,8 @@
 
 #
 #  KeepNote
-#  Copyright (c) 2008-2009 Matt Rasmussen
-#  Author: Matt Rasmussen <rasmus@mit.edu>
+#  Copyright (c) 2008-2011 Matt Rasmussen
+#  Author: Matt Rasmussen <rasmus@alum.mit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -57,22 +57,82 @@ import keepnote.gui.dialog_app_options
 import keepnote.gui.dialog_node_icon
 import keepnote.gui.dialog_wait
 from keepnote.gui.icons import \
-    DEFAULT_QUICK_PICK_ICONS
+    DEFAULT_QUICK_PICK_ICONS, uncache_node_icon
     
 _ = keepnote.translate
 
-
-
+#=============================================================================
 # constants
+
 MAX_RECENT_NOTEBOOKS = 20
 ACCEL_FILE = u"accel.txt"
+IMAGE_DIR = u"images"
 CONTEXT_MENU_ACCEL_PATH = "<main>/context_menu"
 
+DEFAULT_AUTOSAVE_TIME = 10 * 1000 # 10 sec (in msec)
+
+
 # font constants
 DEFAULT_FONT_FAMILY = "Sans"
 DEFAULT_FONT_SIZE = 10
 DEFAULT_FONT = "%s %d" % (DEFAULT_FONT_FAMILY, DEFAULT_FONT_SIZE)
 
+if keepnote.get_platform() == "darwin":
+    CLIPBOARD_NAME = gdk.SELECTION_PRIMARY
+else:
+    CLIPBOARD_NAME = "CLIPBOARD"
+
+
+
+DEFAULT_COLORS_FLOAT = [
+            # lights
+            (1, .6, .6),
+            (1, .8, .6),
+            (1, 1, .6),
+            (.6, 1, .6),
+            (.6, 1, 1),
+            (.6, .6, 1),
+            (1, .6, 1),
+
+            # trues
+            (1, 0, 0),                    
+            (1, .64, 0),
+            (1, 1, 0),                    
+            (0, 1, 0),
+            (0, 1, 1),
+            (0, 0, 1),
+            (1, 0, 1),
+
+            # darks
+            (.5, 0, 0),
+            (.5, .32, 0),
+            (.5, .5, 0),
+            (0, .5, 0),
+            (0, .5, .5),
+            (0, 0, .5),
+            (.5, 0, .5),
+
+            # white, gray, black
+            (1, 1, 1),
+            (.9, .9, .9),
+            (.75, .75, .75),
+            (.5, .5, .5),
+            (.25, .25, .25),
+            (.1, .1, .1),                    
+            (0, 0, 0),                    
+        ]
+
+
+def color_float_to_int8(color):
+    return (int(255*color[0]), int(255*color[1]), int(255*color[2]))
+
+def color_int8_to_str(color):
+    return "#%02x%02x%02x" % (color[0], color[1], color[2])
+
+
+DEFAULT_COLORS = [color_int8_to_str(color_float_to_int8(color))
+                  for color in DEFAULT_COLORS_FLOAT]
+
 
 
 #=============================================================================
@@ -128,7 +188,7 @@ is_pixbuf_cached = pixbufs.is_pixbuf_cached
 def get_resource_image(*path_list):
     """Returns gtk.Image from resource path"""
     
-    filename = get_resource(keepnote.IMAGE_DIR, *path_list)
+    filename = get_resource(IMAGE_DIR, *path_list)
     img = gtk.Image()
     img.set_from_file(filename)
     return img
@@ -136,8 +196,7 @@ def get_resource_image(*path_list):
 def get_resource_pixbuf(*path_list, **options):
     """Returns cached pixbuf from resource path"""
     # raises GError
-    return pixbufs.get_pixbuf(get_resource(keepnote.IMAGE_DIR, *path_list),
-                              **options)
+    return pixbufs.get_pixbuf(get_resource(IMAGE_DIR, *path_list), **options)
 
 
 def fade_pixbuf(pixbuf, alpha=128):
@@ -205,7 +264,6 @@ def update_file_preview(file_chooser, preview):
     file_chooser.set_preview_widget_active(have_preview)
 
 
-
 class FileChooserDialog (gtk.FileChooserDialog):
     """File Chooser Dialog with a persistent path"""
 
@@ -238,6 +296,7 @@ class FileChooserDialog (gtk.FileChooserDialog):
 
 
 
+
 #=============================================================================
 # menu actions
 
@@ -368,8 +427,7 @@ class KeepNote (keepnote.KeepNote):
 
         # shared gui resources
         self._tag_table = keepnote.gui.richtext.richtext_tags.RichTextTagTable()
-        self.app_options_dialog = keepnote.gui.dialog_app_options.ApplicationOptionsDialog(self)
-        self.node_icon_dialog = keepnote.gui.dialog_node_icon.NodeIconDialog(self)
+        self.init_dialogs()
 
         # auto save
         self._auto_saving = False          # True if autosave is on
@@ -381,6 +439,11 @@ class KeepNote (keepnote.KeepNote):
         """Initialize application from disk"""
         keepnote.KeepNote.init(self)        
 
+
+    def init_dialogs(self):
+        self.app_options_dialog = keepnote.gui.dialog_app_options.ApplicationOptionsDialog(self)
+        self.node_icon_dialog = keepnote.gui.dialog_node_icon.NodeIconDialog(self)        
+
         
     def set_lang(self):
         """Set language for application"""
@@ -392,6 +455,9 @@ class KeepNote (keepnote.KeepNote):
                                  keepnote.get_locale_dir())
         gtk.glade.textdomain(keepnote.GETTEXT_DOMAIN)
 
+        # re-initialize dialogs
+        self.init_dialogs()
+        
 
     def load_preferences(self):
         """Load information from preferences"""
@@ -401,7 +467,7 @@ class KeepNote (keepnote.KeepNote):
         # set defaults for auto save
         p = self.pref
         use_autosave = p.get("autosave", default=True)
-        p.get("autosave_time", default=keepnote.DEFAULT_AUTOSAVE_TIME)
+        p.get("autosave_time", default=DEFAULT_AUTOSAVE_TIME)
         
 
         # set style
@@ -411,7 +477,10 @@ class KeepNote (keepnote.KeepNote):
         # let windows load their preferences
         for window in self._windows:
             window.load_preferences()
-        
+
+        for notebook in self._notebooks.itervalues():
+            notebook.enable_fulltext_search(p.get("use_fulltext_search",
+                                                  default=True))
         
         # start autosave loop, if requested
         self.begin_auto_save()
@@ -500,12 +569,17 @@ class KeepNote (keepnote.KeepNote):
             # slow.  If updating the wait dialog wasn't so expensive, I would
             # simply do loading in the background thread.
             def func():
-                conn = self._conns.get(filename)
-                notebook = notebooklib.NoteBook()
-                notebook.load(filename, conn)
-                task.set_result(notebook)
+                try:
+                    conn = self._conns.get(filename)
+                    notebook = notebooklib.NoteBook()
+                    notebook.load(filename, conn)
+                    task.set_result(notebook)
+                except Exception, e:
+                    task.set_exc_info()
+                    task.stop()
                 sem.release() # notify that notebook is loaded
                 return False
+                    
             gobject.idle_add(func)
 
             # wait for notebook to load
@@ -553,18 +627,36 @@ class KeepNote (keepnote.KeepNote):
                        e, task.exc_info()[2])
             return None
 
+        self._init_notebook(notebook)
+            
+        return notebook
+
+
+    def _init_notebook(self, notebook):
+
+        write_needed = False
+
         # install default quick pick icons
         if len(notebook.pref.get_quick_pick_icons()) == 0:
             notebook.pref.set_quick_pick_icons(
                 list(DEFAULT_QUICK_PICK_ICONS))
             notebook.set_preferences_dirty()
+            write_needed = True
 
-            # TODO: use listeners to invoke saving
+        # install default quick pick icons
+        if len(notebook.pref.get("colors", default=())) == 0:
+            notebook.pref.set("colors", DEFAULT_COLORS)
+            notebook.set_preferences_dirty()
+            write_needed = True
+
+        notebook.enable_fulltext_search(self.pref.get("use_fulltext_search",
+                                                      default=True))
+
+
+        # TODO: use listeners to invoke saving
+        if write_needed:
             notebook.write_preferences()
-
-            
-        return notebook
-
+        
 
     def save_notebooks(self, silent=False):
         """Save all opened notebooks"""
@@ -593,8 +685,11 @@ class KeepNote (keepnote.KeepNote):
         """
         keepnote.KeepNote._on_closing_notebook(self, notebook, save)
         
-        if save:
-            self.save()
+        try:
+            if save:
+                self.save()
+        except:
+            keepnote.log_error("Error while closing notebook")
 
         for window in self._windows:
             window.close_notebook(notebook)
@@ -686,8 +781,8 @@ class KeepNote (keepnote.KeepNote):
             elif icon_open_file is not None:
                 node.set_attr("icon_open", icon_open_file)
 
-            node.del_attr("icon_load")
-            node.del_attr("icon_open_load")
+            # uncache pixbufs
+            uncache_node_icon(node)
 
 
 
