@@ -7,8 +7,8 @@
 
 #
 #  KeepNote
-#  Copyright (c) 2008-2009 Matt Rasmussen
-#  Author: Matt Rasmussen <rasmus@mit.edu>
+#  Copyright (c) 2008-2011 Matt Rasmussen
+#  Author: Matt Rasmussen <rasmus@alum.mit.edu>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -214,6 +214,10 @@ class GeneralSection (Section):
         self.xml.get_widget("window_stick_check").set_active(
             app.pref.get("window", "stick"))
 
+        self.xml.get_widget("use_fulltext_check").set_active(
+            app.pref.get("use_fulltext_search", default=True))
+
+
 
     def save_options(self, app):
         if self.xml.get_widget("last_notebook_radio").get_active():
@@ -258,6 +262,10 @@ class GeneralSection (Section):
             "window", "stick",
             self.xml.get_widget("window_stick_check").get_active())
 
+        app.pref.set(
+            "use_fulltext_search",
+            self.xml.get_widget("use_fulltext_check").get_active())
+
 
 class LookAndFeelSection (Section):
     
@@ -393,10 +401,6 @@ class LanguageSection (Section):
             # set default
             app.pref.set("language", "")
 
-        # XXX: may be I should not change translation during execution
-        #if app.pref.language != keepnote.trans.get_lang():
-        #    keepnote.trans.set_lang(app.pref.language)
- 
 
 
 
@@ -486,7 +490,7 @@ class DatesSection (Section):
     
     def __init__(self, key, dialog, app, label=u"", icon="time.png"):
         Section.__init__(self, key, dialog, app, label, icon)
-
+        
         self.date_xml = gtk.glade.XML(get_resource("rc", "keepnote.glade"),
                                    "date_time_frame", keepnote.GETTEXT_DOMAIN)
         self.date_xml.signal_autoconnect(self)
@@ -505,6 +509,46 @@ class DatesSection (Section):
                 self.date_xml.get_widget("date_%s_entry" % name).get_text()))
         
 
+class EditorSection (Section):
+    
+    def __init__(self, key, dialog, app, label=u"", icon=None):
+        Section.__init__(self, key, dialog, app, label, icon)
+
+        w = self.get_default_widget()
+        v = gtk.VBox(False, 5)
+        v.show()
+        w.add(v)
+        
+        # language combo
+        h = gtk.HBox(False, 5); h.show()
+        l = gtk.Label(_("Quote format:")); l.show()
+        h.pack_start(l, False, False, 0)
+        e = gtk.Entry(); e.show()
+        e.set_width_chars(40)
+        
+        # pack entry
+        h.pack_start(e, False, False, 0)
+        v.pack_start(h)
+        self.quote_format = e
+        
+
+
+    def load_options(self, app):
+
+        try:
+            quote_format = app.pref.get("editors", "general", "quote_format")
+            self.quote_format.set_text(quote_format)
+        except:
+            pass
+
+
+    def save_options(self, app):
+        
+        quote_format = self.quote_format.get_text()
+        if quote_format:
+            app.pref.set("editors", "general", "quote_format", quote_format)
+
+
 class AllNoteBooksSection (Section):
     
     def __init__(self, key, dialog, app, label=u"", icon="folder.png"):
@@ -903,6 +947,10 @@ class ApplicationOptionsDialog (object):
             DatesSection("date_and_time", self.dialog, self.app, 
                          _("Date and Time")), 
             "general")
+        self.add_section(
+            EditorSection("ediotr", self.dialog, self.app, 
+                         _("Editor")), 
+            "general")
         self.add_section(
             HelperAppsSection("helper_apps", self.dialog, 
                               self.app, _("Helper Applications")), 
