@@ -364,6 +364,64 @@ def mark_path_outdated(path):
         del _mtime_cache[path]
 
 
+
+def read_attr(filename):
+    """
+    Read a node meta data file. Returns an attr dict
+
+    filename -- a filename or stream
+    """
+
+    try:
+        tree = ET.ElementTree(file=filename)
+    except Exception, e:
+        raise ConnectionError(
+            _(u"Error reading meta data file '%s'" % filename), e)
+
+    # check root
+    root = tree.getroot()
+    if root.tag != "node":
+        raise ConnectionError(_("Root tag is not 'node'"))
+
+    # iterate children
+    attr = {}
+    version = None
+    for child in root:
+        if child.tag == "dict":
+            attr = plist.load_etree(child)
+        if child.tag == "version":
+            version = int(child.text)
+
+    if version:
+        attr["version"] = version
+
+    return attr
+
+
+def write_attr(filename, attr):
+    """
+    Write a node meta file
+
+    filename -- a filename or stream
+    attr     -- attribute dict
+    """
+
+    if isinstance(filename, basestring):
+        out = safefile.open(filename, "w", codec="utf-8")
+        
+    out.write(u'<?xml version="1.0" encoding="UTF-8"?>\n'
+              u'<node>\n'
+              u'<version>%d</version>\n' % 
+              attr.get("version", 
+                       keepnote.notebook.NOTEBOOK_FORMAT_VERSION))
+    plist.dump(attr, out, indent=2, depth=0)
+    out.write(u'</node>\n')
+
+    if isinstance(filename, basestring):
+        out.close()
+
+
+
 #=============================================================================
 # path cache
 
@@ -956,8 +1014,8 @@ class NoteBookConnectionFS (NoteBookConnection):
         """Reads a node from disk"""
         
         metafile = get_node_meta_file(path)
-
-        attr = self._read_attr(metafile)
+        
+        attr = read_attr(metafile)
         attr["parentids"] = ([parentid] if parentid else [])
         if not self._validate_attr(attr):
             self._write_attr(metafile, attr)
@@ -1032,15 +1090,7 @@ class NoteBookConnectionFS (NoteBookConnection):
         self._attr_mask.set_dict(attr)
 
         try:
-            out = safefile.open(filename, "w", codec="utf-8")
-            out.write(u'<?xml version="1.0" encoding="UTF-8"?>\n'
-                      u'<node>\n'
-                      u'<version>%d</version>\n' % 
-                      attr.get("version", 
-                               keepnote.notebook.NOTEBOOK_FORMAT_VERSION))
-            plist.dump(self._attr_mask, out, indent=2, depth=0)
-            out.write(u'</node>\n')
-            out.close()
+            write_attr(filename, self._attr_mask)
         except Exception, e:
             raise ConnectionError(
                 _("Cannot write meta data" + " " + filename + ":" + str(e)), e)
@@ -1048,35 +1098,8 @@ class NoteBookConnectionFS (NoteBookConnection):
 
     def _read_attr(self, filename, recover=True):
         """Read a node meta data file"""
-        
-        try:
-            tree = ET.ElementTree(file=filename)
-        except Exception, e:
-            #if recover:
-            #    self._recover_attr(filename)
-            #    return self._read_attr(filename, recover=False)
-            
-            raise ConnectionError(
-                _(u"Error reading meta data file '%s'" % filename), e)
-
-        # check root
-        root = tree.getroot()
-        if root.tag != "node":
-            raise ConnectionError(_("Root tag is not 'node'"))
-        
-        # iterate children
-        attr = {}
-        version = None
-        for child in root:
-            if child.tag == "dict":
-                attr = plist.load_etree(child)
-            if child.tag == "version":
-                version = int(child.text)
-
-        if version:
-            attr["version"] = version
-        
-        return attr
+                
+        return read_attr(filename)
 
 
     def _recover_attr(self, filename):
