@@ -86,8 +86,8 @@ class NoteBookIndex (NodeIndex):
             self._corrupt = False
             self._need_index = False
             self.con = sqlite.connect(self._index_file, 
-                                      #isolation_level="DEFERRED",
-                                      isolation_level="IMMEDIATE",
+                                      isolation_level="DEFERRED",
+                                      #isolation_level="IMMEDIATE",
                                       check_same_thread=False)
             self.cur = self.con.cursor()
             #self.con.execute(u"PRAGMA read_uncommitted = true;")
@@ -119,12 +119,10 @@ class NoteBookIndex (NodeIndex):
             mtime = time.time()
             self.con.execute("""UPDATE NodeGraph SET mtime = ? WHERE nodeid = ?;""",
                              (mtime, self._nconn.get_rootid()))
-
-            if self.con is not None:
-                try:
-                    self.con.commit()
-                except:
-                    self.open()
+            try:
+                self.con.commit()
+            except:
+                self.open()
         except Exception, e:
             self._on_corrupt(e, sys.exc_info()[2])
 
@@ -191,10 +189,6 @@ class NoteBookIndex (NodeIndex):
             
             # init attribute indexes
             self.init_attrs(self.cur)
-            
-
-            # NOTE: re-claim space in the index
-            con.execute("VACUUM;")
 
             con.commit()
 
@@ -299,6 +293,15 @@ class NoteBookIndex (NodeIndex):
         self._need_index = False
 
 
+    def compact(self):
+        """
+        Try to compact the index by reclaiming space
+        """
+        keepnote.log_message("compacting index '%s'\n" % self._index_file)
+        self.con.execute("VACUUM;")
+        self.con.comment()
+
+
     def get_node_mtime(self, nodeid):
         """Get the last indexed mtime for a node"""
         
@@ -310,7 +313,7 @@ class NoteBookIndex (NodeIndex):
         else:
             return 0.0
 
-    def set_node_mtime(self, nodeid, mtime=None, commit=True):
+    def set_node_mtime(self, nodeid, mtime=None, commit=False):
         """Set the last indexed mtime for a node"""
 
         if mtime is None:
@@ -327,7 +330,7 @@ class NoteBookIndex (NodeIndex):
         return os.stat(self._index_file).st_mtime
 
     
-    def add_node(self, nodeid, parentid, basename, attr, mtime, commit=True):
+    def add_node(self, nodeid, parentid, basename, attr, mtime, commit=False):
         """Add a node to the index"""               
         
         # TODO: remove single parent assumption        
@@ -358,7 +361,7 @@ class NoteBookIndex (NodeIndex):
             self._on_corrupt(e, sys.exc_info()[2])
 
 
-    def remove_node(self, nodeid, commit=True):
+    def remove_node(self, nodeid, commit=False):
         """Remove node from index using nodeid"""
 
         if self.con is None:
